aboutsummaryrefslogtreecommitdiff
path: root/actions/register.php
diff options
context:
space:
mode:
authormarcus <marcus@36083f99-b078-4883-b0ff-0f9b5a30f544>2008-10-03 12:59:49 +0000
committermarcus <marcus@36083f99-b078-4883-b0ff-0f9b5a30f544>2008-10-03 12:59:49 +0000
commit26904c170562c3fccd4eacbcc552e1e53db7fd22 (patch)
treee40752c4f3a5585e8af5b0fcb73f6696b5641e80 /actions/register.php
parentcd51bff9420cf5cdc4a3f093918b7874a256b379 (diff)
downloadelgg-26904c170562c3fccd4eacbcc552e1e53db7fd22.tar.gz
elgg-26904c170562c3fccd4eacbcc552e1e53db7fd22.tar.bz2
Refs #311
git-svn-id: https://code.elgg.org/elgg/trunk@2167 36083f99-b078-4883-b0ff-0f9b5a30f544
Diffstat (limited to 'actions/register.php')
-rw-r--r--actions/register.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/actions/register.php b/actions/register.php
index 84cca17ac..eb5f24c98 100644
--- a/actions/register.php
+++ b/actions/register.php
@@ -50,8 +50,8 @@
if (!$new_user->admin)
$new_user->disable('new_user'); // Now disable if not an admin
- // Send email validation on register only
- request_email_validation($guid);
+ // Send user validation request on register only
+ request_user_validation($guid);
system_message(sprintf(elgg_echo("registerok"),$CONFIG->sitename));